Class: FetchHive::Generated::AgentChatMessagesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fetch_hive/generated/api/agent_chat_messages_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AgentChatMessagesApi

Returns a new instance of AgentChatMessagesApi.



19
20
21
# File 'lib/fetch_hive/generated/api/agent_chat_messages_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/fetch_hive/generated/api/agent_chat_messages_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_public_workspaces_agents_chats_messages(workspace_id, agent_id, chat_id, opts = {}) ⇒ GetPublicWorkspacesAgentsChatsMessages200Response

List messages in a chat Returns messages in the chat ordered chronologically (oldest first).

Parameters:

  • workspace_id (String)

    Workspace UUID

  • agent_id (String)

    Agent UUID

  • chat_id (String)

    Chat UUID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



29
30
31
32
# File 'lib/fetch_hive/generated/api/agent_chat_messages_api.rb', line 29

def get_public_workspaces_agents_chats_messages(workspace_id, agent_id, chat_id, opts = {})
  data, _status_code, _headers = get_public_workspaces_agents_chats_messages_with_http_info(workspace_id, agent_id, chat_id, opts)
  data
end

#get_public_workspaces_agents_chats_messages_with_http_info(workspace_id, agent_id, chat_id, opts = {}) ⇒ Array<(GetPublicWorkspacesAgentsChatsMessages200Response, Integer, Hash)>

List messages in a chat Returns messages in the chat ordered chronologically (oldest first).

Parameters:

  • workspace_id (String)

    Workspace UUID

  • agent_id (String)

    Agent UUID

  • chat_id (String)

    Chat UUID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/fetch_hive/generated/api/agent_chat_messages_api.rb', line 41

def get_public_workspaces_agents_chats_messages_with_http_info(workspace_id, agent_id, chat_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AgentChatMessagesApi.get_public_workspaces_agents_chats_messages ...'
  end
  # verify the required parameter 'workspace_id' is set
  if @api_client.config.client_side_validation && workspace_id.nil?
    fail ArgumentError, "Missing the required parameter 'workspace_id' when calling AgentChatMessagesApi.get_public_workspaces_agents_chats_messages"
  end
  # verify the required parameter 'agent_id' is set
  if @api_client.config.client_side_validation && agent_id.nil?
    fail ArgumentError, "Missing the required parameter 'agent_id' when calling AgentChatMessagesApi.get_public_workspaces_agents_chats_messages"
  end
  # verify the required parameter 'chat_id' is set
  if @api_client.config.client_side_validation && chat_id.nil?
    fail ArgumentError, "Missing the required parameter 'chat_id' when calling AgentChatMessagesApi.get_public_workspaces_agents_chats_messages"
  end
  # resource path
  local_var_path = '/public/workspaces/{workspace_id}/agents/{agent_id}/chats/{chat_id}/messages'.sub('{workspace_id}', CGI.escape(workspace_id.to_s)).sub('{agent_id}', CGI.escape(agent_id.to_s)).sub('{chat_id}', CGI.escape(chat_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetPublicWorkspacesAgentsChatsMessages200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer_auth']

  new_options = opts.merge(
    :operation => :"AgentChatMessagesApi.get_public_workspaces_agents_chats_messages",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AgentChatMessagesApi#get_public_workspaces_agents_chats_messages\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end