Class: FetchHive::Generated::AssetObject

Inherits:
ApiModelBase show all
Defined in:
lib/fetch_hive/generated/models/asset_object.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AssetObject

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::AssetObject` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::AssetObject`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'object_key')
    self.object_key = attributes[:'object_key']
  end

  if attributes.key?(:'file_name')
    self.file_name = attributes[:'file_name']
  else
    self.file_name = nil
  end

  if attributes.key?(:'file_url')
    self.file_url = attributes[:'file_url']
  else
    self.file_url = nil
  end

  if attributes.key?(:'file_url_expires_at')
    self.file_url_expires_at = attributes[:'file_url_expires_at']
  else
    self.file_url_expires_at = nil
  end

  if attributes.key?(:'file_type')
    self.file_type = attributes[:'file_type']
  end

  if attributes.key?(:'file_size')
    self.file_size = attributes[:'file_size']
  end

  if attributes.key?(:'asset_type')
    self.asset_type = attributes[:'asset_type']
  else
    self.asset_type = nil
  end

  if attributes.key?(:'workspace_id')
    self.workspace_id = attributes[:'workspace_id']
  end

  if attributes.key?(:'uploaded_at')
    self.uploaded_at = attributes[:'uploaded_at']
  else
    self.uploaded_at = nil
  end

  if attributes.key?(:'error_message')
    self.error_message = attributes[:'error_message']
  end

  if attributes.key?(:'transcription')
    self.transcription = attributes[:'transcription']
  end
end

Instance Attribute Details

#asset_typeObject

Returns the value of attribute asset_type.



32
33
34
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 32

def asset_type
  @asset_type
end

#error_messageObject

(value may be null)



40
41
42
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 40

def error_message
  @error_message
end

#file_nameObject

Returns the value of attribute file_name.



22
23
24
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 22

def file_name
  @file_name
end

#file_sizeObject

Returns the value of attribute file_size.



30
31
32
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 30

def file_size
  @file_size
end

#file_typeObject

Returns the value of attribute file_type.



28
29
30
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 28

def file_type
  @file_type
end

#file_urlObject

Returns the value of attribute file_url.



24
25
26
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 24

def file_url
  @file_url
end

#file_url_expires_atObject

Returns the value of attribute file_url_expires_at.



26
27
28
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 26

def file_url_expires_at
  @file_url_expires_at
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 18

def id
  @id
end

#object_keyObject

Returns the value of attribute object_key.



20
21
22
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 20

def object_key
  @object_key
end

#transcriptionObject

Returns the value of attribute transcription.



42
43
44
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 42

def transcription
  @transcription
end

#uploaded_atObject

Returns the value of attribute uploaded_at.



37
38
39
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 37

def uploaded_at
  @uploaded_at
end

#workspace_idObject

(value may be null)



35
36
37
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 35

def workspace_id
  @workspace_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 45

def self.attribute_map
  {
    :'id' => :'id',
    :'object_key' => :'object_key',
    :'file_name' => :'file_name',
    :'file_url' => :'file_url',
    :'file_url_expires_at' => :'file_url_expires_at',
    :'file_type' => :'file_type',
    :'file_size' => :'file_size',
    :'asset_type' => :'asset_type',
    :'workspace_id' => :'workspace_id',
    :'uploaded_at' => :'uploaded_at',
    :'error_message' => :'error_message',
    :'transcription' => :'transcription'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 312

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 73

def self.openapi_types
  {
    :'id' => :'String',
    :'object_key' => :'String',
    :'file_name' => :'String',
    :'file_url' => :'String',
    :'file_url_expires_at' => :'Time',
    :'file_type' => :'String',
    :'file_size' => :'Integer',
    :'asset_type' => :'String',
    :'workspace_id' => :'String',
    :'uploaded_at' => :'Time',
    :'error_message' => :'String',
    :'transcription' => :'AssetObjectTranscription'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      object_key == o.object_key &&
      file_name == o.file_name &&
      file_url == o.file_url &&
      file_url_expires_at == o.file_url_expires_at &&
      file_type == o.file_type &&
      file_size == o.file_size &&
      asset_type == o.asset_type &&
      workspace_id == o.workspace_id &&
      uploaded_at == o.uploaded_at &&
      error_message == o.error_message &&
      transcription == o.transcription
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


299
300
301
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 299

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



305
306
307
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 305

def hash
  [id, object_key, file_name, file_url, file_url_expires_at, file_type, file_size, asset_type, workspace_id, uploaded_at, error_message, transcription].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @file_name.nil?
    invalid_properties.push('invalid value for "file_name", file_name cannot be nil.')
  end

  if @file_url.nil?
    invalid_properties.push('invalid value for "file_url", file_url cannot be nil.')
  end

  if @file_url_expires_at.nil?
    invalid_properties.push('invalid value for "file_url_expires_at", file_url_expires_at cannot be nil.')
  end

  if @asset_type.nil?
    invalid_properties.push('invalid value for "asset_type", asset_type cannot be nil.')
  end

  if @uploaded_at.nil?
    invalid_properties.push('invalid value for "uploaded_at", uploaded_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 334

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
215
216
# File 'lib/fetch_hive/generated/models/asset_object.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @file_name.nil?
  return false if @file_url.nil?
  return false if @file_url_expires_at.nil?
  return false if @asset_type.nil?
  return false if @uploaded_at.nil?
  true
end