Class: FetchHive::Generated::AssetsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/fetch_hive/generated/api/assets_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AssetsApi

Returns a new instance of AssetsApi.



19
20
21
# File 'lib/fetch_hive/generated/api/assets_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/fetch_hive/generated/api/assets_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_public_workspaces_assets(workspace_id, opts = {}) ⇒ GetPublicWorkspacesAssets200Response

List public workspace assets Returns assets scoped to the workspace attached to the public API key.

Parameters:

  • workspace_id (String)

    Workspace UUID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/fetch_hive/generated/api/assets_api.rb', line 27

def get_public_workspaces_assets(workspace_id, opts = {})
  data, _status_code, _headers = get_public_workspaces_assets_with_http_info(workspace_id, opts)
  data
end

#get_public_workspaces_assets_with_http_info(workspace_id, opts = {}) ⇒ Array<(GetPublicWorkspacesAssets200Response, Integer, Hash)>

List public workspace assets Returns assets scoped to the workspace attached to the public API key.

Parameters:

  • workspace_id (String)

    Workspace UUID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/fetch_hive/generated/api/assets_api.rb', line 37

def get_public_workspaces_assets_with_http_info(workspace_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.get_public_workspaces_assets ...'
  end
  # verify the required parameter 'workspace_id' is set
  if @api_client.config.client_side_validation && workspace_id.nil?
    fail ArgumentError, "Missing the required parameter 'workspace_id' when calling AssetsApi.get_public_workspaces_assets"
  end
  # resource path
  local_var_path = '/public/workspaces/{workspace_id}/assets'.sub('{workspace_id}', CGI.escape(workspace_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetPublicWorkspacesAssets200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer_auth']

  new_options = opts.merge(
    :operation => :"AssetsApi.get_public_workspaces_assets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#get_public_workspaces_assets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_public_workspaces_assets(workspace_id, opts = {}) ⇒ PostPublicWorkspacesAssets200Response

Upload a public workspace asset Uploads a file and creates a workspace-scoped Asset that can be used as a Hive Agent source.

Parameters:

  • workspace_id (String)

    Workspace UUID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



90
91
92
93
# File 'lib/fetch_hive/generated/api/assets_api.rb', line 90

def post_public_workspaces_assets(workspace_id, opts = {})
  data, _status_code, _headers = post_public_workspaces_assets_with_http_info(workspace_id, opts)
  data
end

#post_public_workspaces_assets_with_http_info(workspace_id, opts = {}) ⇒ Array<(PostPublicWorkspacesAssets200Response, Integer, Hash)>

Upload a public workspace asset Uploads a file and creates a workspace-scoped Asset that can be used as a Hive Agent source.

Parameters:

  • workspace_id (String)

    Workspace UUID

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/fetch_hive/generated/api/assets_api.rb', line 100

def post_public_workspaces_assets_with_http_info(workspace_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AssetsApi.post_public_workspaces_assets ...'
  end
  # verify the required parameter 'workspace_id' is set
  if @api_client.config.client_side_validation && workspace_id.nil?
    fail ArgumentError, "Missing the required parameter 'workspace_id' when calling AssetsApi.post_public_workspaces_assets"
  end
  # resource path
  local_var_path = '/public/workspaces/{workspace_id}/assets'.sub('{workspace_id}', CGI.escape(workspace_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['multipart/form-data'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PostPublicWorkspacesAssets200Response'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['bearer_auth']

  new_options = opts.merge(
    :operation => :"AssetsApi.post_public_workspaces_assets",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AssetsApi#post_public_workspaces_assets\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end