Class: FetchHive::Generated::GetPublicRequests200Response
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FetchHive::Generated::GetPublicRequests200Response
- Defined in:
- lib/fetch_hive/generated/models/get_public_requests200_response.rb
Instance Attribute Summary collapse
-
#data ⇒ Object
(value may be null).
-
#ended_at ⇒ Object
(value may be null).
-
#generated_at ⇒ Object
(value may be null).
-
#id ⇒ Object
Returns the value of attribute id.
-
#message ⇒ Object
(value may be null).
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#request_id ⇒ Object
Returns the value of attribute request_id.
-
#request_type ⇒ Object
Returns the value of attribute request_type.
-
#requestable_id ⇒ Object
(value may be null).
-
#requestable_type ⇒ Object
(value may be null).
-
#started_at ⇒ Object
(value may be null).
-
#status ⇒ Object
Returns the value of attribute status.
-
#user_metadata ⇒ Object
Returns the value of attribute user_metadata.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GetPublicRequests200Response
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GetPublicRequests200Response
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::GetPublicRequests200Response` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::GetPublicRequests200Response`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] else self.request_id = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'request_type') self.request_type = attributes[:'request_type'] else self.request_type = nil end if attributes.key?(:'requestable_type') self.requestable_type = attributes[:'requestable_type'] end if attributes.key?(:'requestable_id') self.requestable_id = attributes[:'requestable_id'] end if attributes.key?(:'message') self. = attributes[:'message'] end if attributes.key?(:'generated_at') self.generated_at = attributes[:'generated_at'] end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] end if attributes.key?(:'ended_at') self.ended_at = attributes[:'ended_at'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'user_metadata') if (value = attributes[:'user_metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'data') if (value = attributes[:'data']).is_a?(Hash) self.data = value end end end |
Instance Attribute Details
#data ⇒ Object
(value may be null)
49 50 51 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 49 def data @data end |
#ended_at ⇒ Object
(value may be null)
42 43 44 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 42 def ended_at @ended_at end |
#generated_at ⇒ Object
(value may be null)
36 37 38 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 36 def generated_at @generated_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 18 def id @id end |
#message ⇒ Object
(value may be null)
33 34 35 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 33 def @message end |
#metadata ⇒ Object
Returns the value of attribute metadata.
44 45 46 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 44 def @metadata end |
#request_id ⇒ Object
Returns the value of attribute request_id.
20 21 22 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 20 def request_id @request_id end |
#request_type ⇒ Object
Returns the value of attribute request_type.
24 25 26 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 24 def request_type @request_type end |
#requestable_id ⇒ Object
(value may be null)
30 31 32 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 30 def requestable_id @requestable_id end |
#requestable_type ⇒ Object
(value may be null)
27 28 29 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 27 def requestable_type @requestable_type end |
#started_at ⇒ Object
(value may be null)
39 40 41 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 39 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
22 23 24 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 22 def status @status end |
#user_metadata ⇒ Object
Returns the value of attribute user_metadata.
46 47 48 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 46 def @user_metadata end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 52 def self.attribute_map { :'id' => :'id', :'request_id' => :'request_id', :'status' => :'status', :'request_type' => :'request_type', :'requestable_type' => :'requestable_type', :'requestable_id' => :'requestable_id', :'message' => :'message', :'generated_at' => :'generated_at', :'started_at' => :'started_at', :'ended_at' => :'ended_at', :'metadata' => :'metadata', :'user_metadata' => :'user_metadata', :'data' => :'data' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 281 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 81 def self.openapi_types { :'id' => :'String', :'request_id' => :'String', :'status' => :'String', :'request_type' => :'String', :'requestable_type' => :'String', :'requestable_id' => :'String', :'message' => :'String', :'generated_at' => :'Time', :'started_at' => :'Time', :'ended_at' => :'Time', :'metadata' => :'Hash<String, Object>', :'user_metadata' => :'Hash<String, Object>', :'data' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 248 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && request_id == o.request_id && status == o.status && request_type == o.request_type && requestable_type == o.requestable_type && requestable_id == o.requestable_id && == o. && generated_at == o.generated_at && started_at == o.started_at && ended_at == o.ended_at && == o. && == o. && data == o.data end |
#eql?(o) ⇒ Boolean
268 269 270 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 268 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
274 275 276 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 274 def hash [id, request_id, status, request_type, requestable_type, requestable_id, , generated_at, started_at, ended_at, , , data].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @request_id.nil? invalid_properties.push('invalid value for "request_id", request_id cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @request_type.nil? invalid_properties.push('invalid value for "request_type", request_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 303 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 |
# File 'lib/fetch_hive/generated/models/get_public_requests200_response.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @request_id.nil? return false if @status.nil? return false if @request_type.nil? true end |