Class: FetchHive::Generated::HiveAgentsApi
- Inherits:
-
Object
- Object
- FetchHive::Generated::HiveAgentsApi
- Defined in:
- lib/fetch_hive/generated/api/hive_agents_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ HiveAgentsApi
constructor
A new instance of HiveAgentsApi.
-
#invoke_hive_agent(invoke_hive_agent_request, opts = {}) ⇒ InvokeHiveAgentResponse
Invoke a Hive Agent Starts a Hive Agent run asynchronously and returns identifiers immediately.
-
#invoke_hive_agent_with_http_info(invoke_hive_agent_request, opts = {}) ⇒ Array<(InvokeHiveAgentResponse, Integer, Hash)>
Invoke a Hive Agent Starts a Hive Agent run asynchronously and returns identifiers immediately.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ HiveAgentsApi
Returns a new instance of HiveAgentsApi.
19 20 21 |
# File 'lib/fetch_hive/generated/api/hive_agents_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/fetch_hive/generated/api/hive_agents_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#invoke_hive_agent(invoke_hive_agent_request, opts = {}) ⇒ InvokeHiveAgentResponse
Invoke a Hive Agent
Starts a Hive Agent run asynchronously and returns identifiers immediately. Hive Agent invocation does not stream and does not wait for the final answer in the HTTP response. A signed callback is sent to async.callback_url when the run completes, fails, or is cancelled. async.enabled must be true and async.callback_url is required.
27 28 29 30 |
# File 'lib/fetch_hive/generated/api/hive_agents_api.rb', line 27 def invoke_hive_agent(invoke_hive_agent_request, opts = {}) data, _status_code, _headers = invoke_hive_agent_with_http_info(invoke_hive_agent_request, opts) data end |
#invoke_hive_agent_with_http_info(invoke_hive_agent_request, opts = {}) ⇒ Array<(InvokeHiveAgentResponse, Integer, Hash)>
Invoke a Hive Agent Starts a Hive Agent run asynchronously and returns identifiers immediately. Hive Agent invocation does not stream and does not wait for the final answer in the HTTP response. A signed callback is sent to `async.callback_url` when the run completes, fails, or is cancelled. `async.enabled` must be `true` and `async.callback_url` is required.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/fetch_hive/generated/api/hive_agents_api.rb', line 37 def invoke_hive_agent_with_http_info(invoke_hive_agent_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: HiveAgentsApi.invoke_hive_agent ...' end # verify the required parameter 'invoke_hive_agent_request' is set if @api_client.config.client_side_validation && invoke_hive_agent_request.nil? fail ArgumentError, "Missing the required parameter 'invoke_hive_agent_request' when calling HiveAgentsApi.invoke_hive_agent" end # resource path local_var_path = '/hive-agent/invoke' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(invoke_hive_agent_request) # return_type return_type = opts[:debug_return_type] || 'InvokeHiveAgentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"HiveAgentsApi.invoke_hive_agent", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: HiveAgentsApi#invoke_hive_agent\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |