Class: FetchHive::Generated::InvokeAgentRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/invoke_agent_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvokeAgentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::InvokeAgentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::InvokeAgentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'agent')
    self.agent = attributes[:'agent']
  else
    self.agent = nil
  end

  if attributes.key?(:'thread_id')
    self.thread_id = attributes[:'thread_id']
  else
    self.thread_id = ''
  end

  if attributes.key?(:'streaming')
    self.streaming = attributes[:'streaming']
  else
    self.streaming = false
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end

  if attributes.key?(:'attachments')
    if (value = attributes[:'attachments']).is_a?(Array)
      self.attachments = value
    end
  end

  if attributes.key?(:'known_artifact_refs')
    if (value = attributes[:'known_artifact_refs']).is_a?(Array)
      self.known_artifact_refs = value
    end
  end

  if attributes.key?(:'artifact_refs')
    if (value = attributes[:'artifact_refs']).is_a?(Array)
      self.artifact_refs = value
    end
  end
end

Instance Attribute Details

#agentObject

Slug of the agent to invoke.



22
23
24
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 22

def agent
  @agent
end

#artifact_refsObject

Artifact UUIDs explicitly selected for the current turn. In a caller-managed session every value must also appear in known_artifact_refs.



46
47
48
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 46

def artifact_refs
  @artifact_refs
end

#attachmentsObject

External HTTPS documents/images or uploaded Asset descriptors for the current turn. Combined with artifact_refs, at most five items are accepted. External audio URLs are unsupported.



40
41
42
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 40

def attachments
  @attachments
end

#known_artifact_refsObject

Account/workspace-owned Asset UUIDs available for lightweight discovery in caller-managed sessions. Persistent threads derive this list from the saved chat.



43
44
45
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 43

def known_artifact_refs
  @known_artifact_refs
end

#messageObject

The user's message to send to the agent.



19
20
21
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 19

def message
  @message
end

#messagesObject

Ephemeral conversation history supplied by the caller. Not stored in the database. Takes precedence over thread_id history when both are provided.



37
38
39
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 37

def messages
  @messages
end

#metadataObject

Flat caller-defined metadata stored separately from internal metadata for log display and filtering. Keys must be non-empty strings; values must be strings, numbers, booleans, or null.



34
35
36
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 34

def 
  @metadata
end

#streamingObject

When true the response is a Server-Sent Events stream.



28
29
30
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 28

def streaming
  @streaming
end

#thread_idObject

Find-or-create a persistent conversation thread by this caller- supplied string. Leave empty to start a stateless invocation.



25
26
27
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 25

def thread_id
  @thread_id
end

#userObject

Optional opaque caller identifier for audit logging.



31
32
33
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 31

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 49

def self.attribute_map
  {
    :'message' => :'message',
    :'agent' => :'agent',
    :'thread_id' => :'thread_id',
    :'streaming' => :'streaming',
    :'user' => :'user',
    :'metadata' => :'metadata',
    :'messages' => :'messages',
    :'attachments' => :'attachments',
    :'known_artifact_refs' => :'known_artifact_refs',
    :'artifact_refs' => :'artifact_refs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 305

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 75

def self.openapi_types
  {
    :'message' => :'String',
    :'agent' => :'String',
    :'thread_id' => :'String',
    :'streaming' => :'Boolean',
    :'user' => :'String',
    :'metadata' => :'Hash<String, MetadataValue>',
    :'messages' => :'Array<AgentMessage>',
    :'attachments' => :'Array<AgentAttachment>',
    :'known_artifact_refs' => :'Array<String>',
    :'artifact_refs' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



275
276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 275

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message == o.message &&
      agent == o.agent &&
      thread_id == o.thread_id &&
      streaming == o.streaming &&
      user == o.user &&
       == o. &&
      messages == o.messages &&
      attachments == o.attachments &&
      known_artifact_refs == o.known_artifact_refs &&
      artifact_refs == o.artifact_refs
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


292
293
294
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 292

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



298
299
300
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 298

def hash
  [message, agent, thread_id, streaming, user, , messages, attachments, known_artifact_refs, artifact_refs].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @agent.nil?
    invalid_properties.push('invalid value for "agent", agent cannot be nil.')
  end

  if !@attachments.nil? && @attachments.length > 5
    invalid_properties.push('invalid value for "attachments", number of items must be less than or equal to 5.')
  end

  if !@known_artifact_refs.nil? && @known_artifact_refs.length > 50
    invalid_properties.push('invalid value for "known_artifact_refs", number of items must be less than or equal to 50.')
  end

  if !@artifact_refs.nil? && @artifact_refs.length > 5
    invalid_properties.push('invalid value for "artifact_refs", number of items must be less than or equal to 5.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 327

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @message.nil?
  return false if @agent.nil?
  return false if !@attachments.nil? && @attachments.length > 5
  return false if !@known_artifact_refs.nil? && @known_artifact_refs.length > 50
  return false if !@artifact_refs.nil? && @artifact_refs.length > 5
  true
end