Class: FetchHive::Generated::InvokePromptRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/invoke_prompt_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvokePromptRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::InvokePromptRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::InvokePromptRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'deployment')
    self.deployment = attributes[:'deployment']
  else
    self.deployment = nil
  end

  if attributes.key?(:'variant')
    self.variant = attributes[:'variant']
  else
    self.variant = ''
  end

  if attributes.key?(:'inputs')
    if (value = attributes[:'inputs']).is_a?(Hash)
      self.inputs = value
    end
  end

  if attributes.key?(:'streaming')
    self.streaming = attributes[:'streaming']
  else
    self.streaming = false
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end
end

Instance Attribute Details

#deploymentObject

Slug of the prompt deployment to invoke.



19
20
21
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 19

def deployment
  @deployment
end

#inputsObject

Key-value pairs that are substituted into the prompt template. Values may be strings, numbers, booleans, arrays, or nested objects.



25
26
27
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 25

def inputs
  @inputs
end

#streamingObject

When ‘true` the response is a Server-Sent Events stream rather than a single JSON body.



28
29
30
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 28

def streaming
  @streaming
end

#userObject

Optional opaque caller identifier for audit logging.



31
32
33
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 31

def user
  @user
end

#variantObject

Optional variant name to override the default.



22
23
24
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 22

def variant
  @variant
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 34

def self.attribute_map
  {
    :'deployment' => :'deployment',
    :'variant' => :'variant',
    :'inputs' => :'inputs',
    :'streaming' => :'streaming',
    :'user' => :'user'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 173

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 55

def self.openapi_types
  {
    :'deployment' => :'String',
    :'variant' => :'String',
    :'inputs' => :'Hash<String, Object>',
    :'streaming' => :'Boolean',
    :'user' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
155
156
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      deployment == o.deployment &&
      variant == o.variant &&
      inputs == o.inputs &&
      streaming == o.streaming &&
      user == o.user
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


160
161
162
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 160

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



166
167
168
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 166

def hash
  [deployment, variant, inputs, streaming, user].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @deployment.nil?
    invalid_properties.push('invalid value for "deployment", deployment cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 195

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
# File 'lib/fetch_hive/generated/models/invoke_prompt_request.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @deployment.nil?
  true
end