Class: FetchHive::Generated::InvokeWorkflowRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/invoke_workflow_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvokeWorkflowRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::InvokeWorkflowRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::InvokeWorkflowRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'deployment')
    self.deployment = attributes[:'deployment']
  else
    self.deployment = nil
  end

  if attributes.key?(:'variant')
    self.variant = attributes[:'variant']
  else
    self.variant = ''
  end

  if attributes.key?(:'inputs')
    if (value = attributes[:'inputs']).is_a?(Hash)
      self.inputs = value
    end
  end

  if attributes.key?(:'async')
    self.async = attributes[:'async']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end
end

Instance Attribute Details

#asyncObject

Returns the value of attribute async.



27
28
29
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 27

def async
  @async
end

#deploymentObject

Slug of the workflow deployment to invoke.



19
20
21
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 19

def deployment
  @deployment
end

#inputsObject

Input variables for the workflow.



25
26
27
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 25

def inputs
  @inputs
end

#metadataObject

Flat caller-defined metadata stored separately from internal metadata for log display and filtering. Keys must be non-empty strings; values must be strings, numbers, booleans, or null.



33
34
35
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 33

def 
  @metadata
end

#userObject

Optional opaque caller identifier for audit logging.



30
31
32
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 30

def user
  @user
end

#variantObject

Optional variant name to override the default.



22
23
24
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 22

def variant
  @variant
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



48
49
50
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 48

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



53
54
55
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 53

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 36

def self.attribute_map
  {
    :'deployment' => :'deployment',
    :'variant' => :'variant',
    :'inputs' => :'inputs',
    :'async' => :'async',
    :'user' => :'user',
    :'metadata' => :'metadata'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 182

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



58
59
60
61
62
63
64
65
66
67
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 58

def self.openapi_types
  {
    :'deployment' => :'String',
    :'variant' => :'String',
    :'inputs' => :'Hash<String, Object>',
    :'async' => :'AsyncConfig',
    :'user' => :'String',
    :'metadata' => :'Hash<String, MetadataValue>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
162
163
164
165
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      deployment == o.deployment &&
      variant == o.variant &&
      inputs == o.inputs &&
      async == o.async &&
      user == o.user &&
       == o.
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


169
170
171
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 169

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



175
176
177
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 175

def hash
  [deployment, variant, inputs, async, user, ].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @deployment.nil?
    invalid_properties.push('invalid value for "deployment", deployment cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
142
# File 'lib/fetch_hive/generated/models/invoke_workflow_request.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @deployment.nil?
  true
end