Class: FetchHive::Generated::InvokeWorkflowResponse
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FetchHive::Generated::InvokeWorkflowResponse
- Defined in:
- lib/fetch_hive/generated/models/invoke_workflow_response.rb
Overview
Synchronous workflow result.
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#error ⇒ Object
Error message when ‘status` is `failed`.
-
#output ⇒ Object
The workflow’s final output value.
-
#request_id ⇒ Object
Unique identifier for this invocation.
-
#run_id ⇒ Object
Workflow run identifier.
-
#status ⇒ Object
Final status of the workflow run.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InvokeWorkflowResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InvokeWorkflowResponse
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::InvokeWorkflowResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::InvokeWorkflowResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.key?(:'run_id') self.run_id = attributes[:'run_id'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'output') self.output = attributes[:'output'] end if attributes.key?(:'error') self.error = attributes[:'error'] end end |
Instance Attribute Details
#error ⇒ Object
Error message when ‘status` is `failed`.
32 33 34 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 32 def error @error end |
#output ⇒ Object
The workflow’s final output value. May contain serialised JSON; parse client-side as needed.
29 30 31 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 29 def output @output end |
#request_id ⇒ Object
Unique identifier for this invocation.
20 21 22 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 20 def request_id @request_id end |
#run_id ⇒ Object
Workflow run identifier.
23 24 25 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 23 def run_id @run_id end |
#status ⇒ Object
Final status of the workflow run.
26 27 28 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 26 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 57 def self.attribute_map { :'request_id' => :'request_id', :'run_id' => :'run_id', :'status' => :'status', :'output' => :'output', :'error' => :'error' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 185 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
89 90 91 92 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 89 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 78 def self.openapi_types { :'request_id' => :'String', :'run_id' => :'String', :'status' => :'String', :'output' => :'String', :'error' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && request_id == o.request_id && run_id == o.run_id && status == o.status && output == o.output && error == o.error end |
#eql?(o) ⇒ Boolean
172 173 174 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 172 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
178 179 180 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 178 def hash [request_id, run_id, status, output, error].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
133 134 135 136 137 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 133 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 207 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
141 142 143 144 145 146 |
# File 'lib/fetch_hive/generated/models/invoke_workflow_response.rb', line 141 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' status_validator = EnumAttributeValidator.new('String', ["completed", "failed"]) return false unless status_validator.valid?(@status) true end |