Class: FetchHive::Generated::PatchPublicWorkspacesAgentsRequestAgent

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchPublicWorkspacesAgentsRequestAgent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 118

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::PatchPublicWorkspacesAgentsRequestAgent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::PatchPublicWorkspacesAgentsRequestAgent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'llm_model')
    self.llm_model = attributes[:'llm_model']
  end

  if attributes.key?(:'model_type')
    self.model_type = attributes[:'model_type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'instruction_prompt')
    self.instruction_prompt = attributes[:'instruction_prompt']
  end

  if attributes.key?(:'temperature')
    self.temperature = attributes[:'temperature']
  end

  if attributes.key?(:'max_token')
    self.max_token = attributes[:'max_token']
  end

  if attributes.key?(:'max_thinking_token')
    self.max_thinking_token = attributes[:'max_thinking_token']
  end

  if attributes.key?(:'anthropic_prompt_cache_ttl')
    self.anthropic_prompt_cache_ttl = attributes[:'anthropic_prompt_cache_ttl']
  end

  if attributes.key?(:'reasoning_effort')
    self.reasoning_effort = attributes[:'reasoning_effort']
  end

  if attributes.key?(:'tool_choice')
    self.tool_choice = attributes[:'tool_choice']
  end

  if attributes.key?(:'max_tool_calls')
    self.max_tool_calls = attributes[:'max_tool_calls']
  end
end

Instance Attribute Details

#anthropic_prompt_cache_ttlObject

Returns the value of attribute anthropic_prompt_cache_ttl.



34
35
36
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 34

def anthropic_prompt_cache_ttl
  @anthropic_prompt_cache_ttl
end

#descriptionObject

Returns the value of attribute description.



24
25
26
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 24

def description
  @description
end

#instruction_promptObject

Returns the value of attribute instruction_prompt.



26
27
28
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 26

def instruction_prompt
  @instruction_prompt
end

#llm_modelObject

Returns the value of attribute llm_model.



20
21
22
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 20

def llm_model
  @llm_model
end

#max_thinking_tokenObject

Returns the value of attribute max_thinking_token.



32
33
34
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 32

def max_thinking_token
  @max_thinking_token
end

#max_tokenObject

Returns the value of attribute max_token.



30
31
32
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 30

def max_token
  @max_token
end

#max_tool_callsObject

Returns the value of attribute max_tool_calls.



40
41
42
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 40

def max_tool_calls
  @max_tool_calls
end

#model_typeObject

Returns the value of attribute model_type.



22
23
24
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 22

def model_type
  @model_type
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 18

def name
  @name
end

#reasoning_effortObject

Returns the value of attribute reasoning_effort.



36
37
38
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 36

def reasoning_effort
  @reasoning_effort
end

#temperatureObject

Returns the value of attribute temperature.



28
29
30
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 28

def temperature
  @temperature
end

#tool_choiceObject

Returns the value of attribute tool_choice.



38
39
40
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 38

def tool_choice
  @tool_choice
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 65

def self.attribute_map
  {
    :'name' => :'name',
    :'llm_model' => :'llm_model',
    :'model_type' => :'model_type',
    :'description' => :'description',
    :'instruction_prompt' => :'instruction_prompt',
    :'temperature' => :'temperature',
    :'max_token' => :'max_token',
    :'max_thinking_token' => :'max_thinking_token',
    :'anthropic_prompt_cache_ttl' => :'anthropic_prompt_cache_ttl',
    :'reasoning_effort' => :'reasoning_effort',
    :'tool_choice' => :'tool_choice',
    :'max_tool_calls' => :'max_tool_calls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 266

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



111
112
113
114
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 111

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 93

def self.openapi_types
  {
    :'name' => :'String',
    :'llm_model' => :'String',
    :'model_type' => :'String',
    :'description' => :'String',
    :'instruction_prompt' => :'String',
    :'temperature' => :'Float',
    :'max_token' => :'Integer',
    :'max_thinking_token' => :'Integer',
    :'anthropic_prompt_cache_ttl' => :'String',
    :'reasoning_effort' => :'String',
    :'tool_choice' => :'String',
    :'max_tool_calls' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 234

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      llm_model == o.llm_model &&
      model_type == o.model_type &&
      description == o.description &&
      instruction_prompt == o.instruction_prompt &&
      temperature == o.temperature &&
      max_token == o.max_token &&
      max_thinking_token == o.max_thinking_token &&
      anthropic_prompt_cache_ttl == o.anthropic_prompt_cache_ttl &&
      reasoning_effort == o.reasoning_effort &&
      tool_choice == o.tool_choice &&
      max_tool_calls == o.max_tool_calls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 253

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



259
260
261
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 259

def hash
  [name, llm_model, model_type, description, instruction_prompt, temperature, max_token, max_thinking_token, anthropic_prompt_cache_ttl, reasoning_effort, tool_choice, max_tool_calls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



288
289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 288

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
198
199
200
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_agents_request_agent.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  anthropic_prompt_cache_ttl_validator = EnumAttributeValidator.new('String', ["disabled", "5m", "1h"])
  return false unless anthropic_prompt_cache_ttl_validator.valid?(@anthropic_prompt_cache_ttl)
  reasoning_effort_validator = EnumAttributeValidator.new('String', ["low", "medium", "high", "minimal", "xhigh", "max"])
  return false unless reasoning_effort_validator.valid?(@reasoning_effort)
  tool_choice_validator = EnumAttributeValidator.new('String', ["none", "auto", "required"])
  return false unless tool_choice_validator.valid?(@tool_choice)
  true
end