Class: FetchHive::Generated::PatchPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FetchHive::Generated::PatchPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem
- Defined in:
- lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#chunk_overlap ⇒ Object
Returns the value of attribute chunk_overlap.
-
#chunking_strategy ⇒ Object
Returns the value of attribute chunking_strategy.
-
#data_content ⇒ Object
Returns the value of attribute data_content.
-
#data_query ⇒ Object
Returns the value of attribute data_query.
-
#delete_email_data ⇒ Object
Returns the value of attribute delete_email_data.
-
#delete_telephone_data ⇒ Object
Returns the value of attribute delete_telephone_data.
-
#description ⇒ Object
Returns the value of attribute description.
-
#maximum_chunk_length ⇒ Object
Returns the value of attribute maximum_chunk_length.
-
#name ⇒ Object
Returns the value of attribute name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::PatchPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::PatchPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'data_content') self.data_content = attributes[:'data_content'] end if attributes.key?(:'data_query') self.data_query = attributes[:'data_query'] end if attributes.key?(:'delete_email_data') self.delete_email_data = attributes[:'delete_email_data'] end if attributes.key?(:'delete_telephone_data') self.delete_telephone_data = attributes[:'delete_telephone_data'] end if attributes.key?(:'chunking_strategy') self.chunking_strategy = attributes[:'chunking_strategy'] end if attributes.key?(:'chunk_overlap') self.chunk_overlap = attributes[:'chunk_overlap'] end if attributes.key?(:'maximum_chunk_length') self.maximum_chunk_length = attributes[:'maximum_chunk_length'] end end |
Instance Attribute Details
#chunk_overlap ⇒ Object
Returns the value of attribute chunk_overlap.
32 33 34 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 32 def chunk_overlap @chunk_overlap end |
#chunking_strategy ⇒ Object
Returns the value of attribute chunking_strategy.
30 31 32 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 30 def chunking_strategy @chunking_strategy end |
#data_content ⇒ Object
Returns the value of attribute data_content.
22 23 24 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 22 def data_content @data_content end |
#data_query ⇒ Object
Returns the value of attribute data_query.
24 25 26 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 24 def data_query @data_query end |
#delete_email_data ⇒ Object
Returns the value of attribute delete_email_data.
26 27 28 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 26 def delete_email_data @delete_email_data end |
#delete_telephone_data ⇒ Object
Returns the value of attribute delete_telephone_data.
28 29 30 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 28 def delete_telephone_data @delete_telephone_data end |
#description ⇒ Object
Returns the value of attribute description.
20 21 22 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 20 def description @description end |
#maximum_chunk_length ⇒ Object
Returns the value of attribute maximum_chunk_length.
34 35 36 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 34 def maximum_chunk_length @maximum_chunk_length end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 18 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 59 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'data_content' => :'data_content', :'data_query' => :'data_query', :'delete_email_data' => :'delete_email_data', :'delete_telephone_data' => :'delete_telephone_data', :'chunking_strategy' => :'chunking_strategy', :'chunk_overlap' => :'chunk_overlap', :'maximum_chunk_length' => :'maximum_chunk_length' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 84 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'data_content' => :'String', :'data_query' => :'String', :'delete_email_data' => :'String', :'delete_telephone_data' => :'String', :'chunking_strategy' => :'String', :'chunk_overlap' => :'Integer', :'maximum_chunk_length' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && data_content == o.data_content && data_query == o.data_query && delete_email_data == o.delete_email_data && delete_telephone_data == o.delete_telephone_data && chunking_strategy == o.chunking_strategy && chunk_overlap == o.chunk_overlap && maximum_chunk_length == o.maximum_chunk_length end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 220 def hash [name, description, data_content, data_query, delete_email_data, delete_telephone_data, chunking_strategy, chunk_overlap, maximum_chunk_length].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
159 160 161 162 163 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 159 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 |
# File 'lib/fetch_hive/generated/models/patch_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' delete_email_data_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"]) return false unless delete_email_data_validator.valid?(@delete_email_data) delete_telephone_data_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"]) return false unless delete_telephone_data_validator.valid?(@delete_telephone_data) true end |