Class: FetchHive::Generated::PostPublicWorkspacesAgentsRequestAgent

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostPublicWorkspacesAgentsRequestAgent

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::PostPublicWorkspacesAgentsRequestAgent` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::PostPublicWorkspacesAgentsRequestAgent`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'llm_model')
    self.llm_model = attributes[:'llm_model']
  else
    self.llm_model = nil
  end

  if attributes.key?(:'model_type')
    self.model_type = attributes[:'model_type']
  else
    self.model_type = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'instruction_prompt')
    self.instruction_prompt = attributes[:'instruction_prompt']
  end

  if attributes.key?(:'temperature')
    self.temperature = attributes[:'temperature']
  end

  if attributes.key?(:'max_token')
    self.max_token = attributes[:'max_token']
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



24
25
26
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 24

def description
  @description
end

#instruction_promptObject

Returns the value of attribute instruction_prompt.



26
27
28
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 26

def instruction_prompt
  @instruction_prompt
end

#llm_modelObject

Returns the value of attribute llm_model.



20
21
22
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 20

def llm_model
  @llm_model
end

#max_tokenObject

Returns the value of attribute max_token.



30
31
32
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 30

def max_token
  @max_token
end

#model_typeObject

Returns the value of attribute model_type.



22
23
24
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 22

def model_type
  @model_type
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 18

def name
  @name
end

#temperatureObject

Returns the value of attribute temperature.



28
29
30
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 28

def temperature
  @temperature
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'llm_model' => :'llm_model',
    :'model_type' => :'model_type',
    :'description' => :'description',
    :'instruction_prompt' => :'instruction_prompt',
    :'temperature' => :'temperature',
    :'max_token' => :'max_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 214

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 56

def self.openapi_types
  {
    :'name' => :'String',
    :'llm_model' => :'String',
    :'model_type' => :'String',
    :'description' => :'String',
    :'instruction_prompt' => :'String',
    :'temperature' => :'Float',
    :'max_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      llm_model == o.llm_model &&
      model_type == o.model_type &&
      description == o.description &&
      instruction_prompt == o.instruction_prompt &&
      temperature == o.temperature &&
      max_token == o.max_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 207

def hash
  [name, llm_model, model_type, description, instruction_prompt, temperature, max_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @llm_model.nil?
    invalid_properties.push('invalid value for "llm_model", llm_model cannot be nil.')
  end

  if @model_type.nil?
    invalid_properties.push('invalid value for "model_type", model_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 236

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_request_agent.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @llm_model.nil?
  return false if @model_type.nil?
  true
end