Class: FetchHive::Generated::PostPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::PostPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::PostPublicWorkspacesKnowledgeBasesItemsRequestKnowledgeBaseItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'item_type')
    self.item_type = attributes[:'item_type']
  end

  if attributes.key?(:'response_type')
    self.response_type = attributes[:'response_type']
  end

  if attributes.key?(:'data_content')
    self.data_content = attributes[:'data_content']
  end

  if attributes.key?(:'data_query')
    self.data_query = attributes[:'data_query']
  end

  if attributes.key?(:'delete_email_data')
    self.delete_email_data = attributes[:'delete_email_data']
  end

  if attributes.key?(:'delete_telephone_data')
    self.delete_telephone_data = attributes[:'delete_telephone_data']
  end

  if attributes.key?(:'chunking_strategy')
    self.chunking_strategy = attributes[:'chunking_strategy']
  end

  if attributes.key?(:'chunk_overlap')
    self.chunk_overlap = attributes[:'chunk_overlap']
  end

  if attributes.key?(:'maximum_chunk_length')
    self.maximum_chunk_length = attributes[:'maximum_chunk_length']
  end

  if attributes.key?(:'asset_id')
    self.asset_id = attributes[:'asset_id']
  end
end

Instance Attribute Details

#asset_idObject

Returns the value of attribute asset_id.



41
42
43
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 41

def asset_id
  @asset_id
end

#chunk_overlapObject

Returns the value of attribute chunk_overlap.



37
38
39
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 37

def chunk_overlap
  @chunk_overlap
end

#chunking_strategyObject

Returns the value of attribute chunking_strategy.



35
36
37
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 35

def chunking_strategy
  @chunking_strategy
end

#data_contentObject

Returns the value of attribute data_content.



26
27
28
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 26

def data_content
  @data_content
end

#data_queryObject

(value may be null)



29
30
31
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 29

def data_query
  @data_query
end

#delete_email_dataObject

Returns the value of attribute delete_email_data.



31
32
33
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 31

def delete_email_data
  @delete_email_data
end

#delete_telephone_dataObject

Returns the value of attribute delete_telephone_data.



33
34
35
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 33

def delete_telephone_data
  @delete_telephone_data
end

#descriptionObject

Returns the value of attribute description.



20
21
22
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 20

def description
  @description
end

#item_typeObject

Returns the value of attribute item_type.



22
23
24
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 22

def item_type
  @item_type
end

#maximum_chunk_lengthObject

Returns the value of attribute maximum_chunk_length.



39
40
41
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 39

def maximum_chunk_length
  @maximum_chunk_length
end

#nameObject

Returns the value of attribute name.



18
19
20
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 18

def name
  @name
end

#response_typeObject

Returns the value of attribute response_type.



24
25
26
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 24

def response_type
  @response_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 66

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'item_type' => :'item_type',
    :'response_type' => :'response_type',
    :'data_content' => :'data_content',
    :'data_query' => :'data_query',
    :'delete_email_data' => :'delete_email_data',
    :'delete_telephone_data' => :'delete_telephone_data',
    :'chunking_strategy' => :'chunking_strategy',
    :'chunk_overlap' => :'chunk_overlap',
    :'maximum_chunk_length' => :'maximum_chunk_length',
    :'asset_id' => :'asset_id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 284

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 94

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'item_type' => :'String',
    :'response_type' => :'String',
    :'data_content' => :'String',
    :'data_query' => :'String',
    :'delete_email_data' => :'String',
    :'delete_telephone_data' => :'String',
    :'chunking_strategy' => :'String',
    :'chunk_overlap' => :'Integer',
    :'maximum_chunk_length' => :'Integer',
    :'asset_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 252

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      item_type == o.item_type &&
      response_type == o.response_type &&
      data_content == o.data_content &&
      data_query == o.data_query &&
      delete_email_data == o.delete_email_data &&
      delete_telephone_data == o.delete_telephone_data &&
      chunking_strategy == o.chunking_strategy &&
      chunk_overlap == o.chunk_overlap &&
      maximum_chunk_length == o.maximum_chunk_length &&
      asset_id == o.asset_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


271
272
273
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 271

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



277
278
279
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 277

def hash
  [name, description, item_type, response_type, data_content, data_query, delete_email_data, delete_telephone_data, chunking_strategy, chunk_overlap, maximum_chunk_length, asset_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
191
192
193
194
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 306

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



198
199
200
201
202
203
204
205
206
207
208
# File 'lib/fetch_hive/generated/models/post_public_workspaces_knowledge_bases_items_request_knowledge_base_item.rb', line 198

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  item_type_validator = EnumAttributeValidator.new('String', ["custom", "website_scrape", "document"])
  return false unless item_type_validator.valid?(@item_type)
  delete_email_data_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"])
  return false unless delete_email_data_validator.valid?(@delete_email_data)
  delete_telephone_data_validator = EnumAttributeValidator.new('String', ["enabled", "disabled"])
  return false unless delete_telephone_data_validator.valid?(@delete_telephone_data)
  true
end