Class: FetchHive::Generated::AgentsApi
- Inherits:
-
Object
- Object
- FetchHive::Generated::AgentsApi
- Defined in:
- lib/fetch_hive/generated/api/agents_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ AgentsApi
constructor
A new instance of AgentsApi.
-
#invoke_agent(invoke_agent_request, opts = {}) ⇒ InvokeAgentResponse
Invoke an agent Sends a message to a configured agent and returns its response.
-
#invoke_agent_with_http_info(invoke_agent_request, opts = {}) ⇒ Array<(InvokeAgentResponse, Integer, Hash)>
Invoke an agent Sends a message to a configured agent and returns its response.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/fetch_hive/generated/api/agents_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#invoke_agent(invoke_agent_request, opts = {}) ⇒ InvokeAgentResponse
Invoke an agent Sends a message to a configured agent and returns its response. Agents can use tools, maintain conversation history via ‘thread_id`, or accept ephemeral history via the `messages` field. Set `streaming: true` to receive a Server-Sent Events stream. Each `data:` line contains a JSON object of type `SseChunk`. Image URLs can be supplied in `image_urls` for multimodal inputs (must be HTTPS).
27 28 29 30 |
# File 'lib/fetch_hive/generated/api/agents_api.rb', line 27 def invoke_agent(invoke_agent_request, opts = {}) data, _status_code, _headers = invoke_agent_with_http_info(invoke_agent_request, opts) data end |
#invoke_agent_with_http_info(invoke_agent_request, opts = {}) ⇒ Array<(InvokeAgentResponse, Integer, Hash)>
Invoke an agent Sends a message to a configured agent and returns its response. Agents can use tools, maintain conversation history via `thread_id`, or accept ephemeral history via the `messages` field. Set `streaming: true` to receive a Server-Sent Events stream. Each `data:` line contains a JSON object of type `SseChunk`. Image URLs can be supplied in `image_urls` for multimodal inputs (must be HTTPS).
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/fetch_hive/generated/api/agents_api.rb', line 37 def invoke_agent_with_http_info(invoke_agent_request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AgentsApi.invoke_agent ...' end # verify the required parameter 'invoke_agent_request' is set if @api_client.config.client_side_validation && invoke_agent_request.nil? fail ArgumentError, "Missing the required parameter 'invoke_agent_request' when calling AgentsApi.invoke_agent" end # resource path local_var_path = '/agent/invoke' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(invoke_agent_request) # return_type return_type = opts[:debug_return_type] || 'InvokeAgentResponse' # auth_names auth_names = opts[:debug_auth_names] || ['BearerAuth'] = opts.merge( :operation => :"AgentsApi.invoke_agent", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AgentsApi#invoke_agent\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |