Class: FetchHive::Generated::InvokeAgentRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/fetch_hive/generated/models/invoke_agent_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InvokeAgentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::InvokeAgentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::InvokeAgentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'agent')
    self.agent = attributes[:'agent']
  else
    self.agent = nil
  end

  if attributes.key?(:'thread_id')
    self.thread_id = attributes[:'thread_id']
  else
    self.thread_id = ''
  end

  if attributes.key?(:'streaming')
    self.streaming = attributes[:'streaming']
  else
    self.streaming = false
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end

  if attributes.key?(:'image_urls')
    if (value = attributes[:'image_urls']).is_a?(Array)
      self.image_urls = value
    end
  end
end

Instance Attribute Details

#agentObject

Slug of the agent to invoke.



22
23
24
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 22

def agent
  @agent
end

#image_urlsObject

HTTPS image URLs attached to the current ‘message` for multimodal inputs. All URLs must start with `https://`.



40
41
42
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 40

def image_urls
  @image_urls
end

#messageObject

The user’s message to send to the agent.



19
20
21
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 19

def message
  @message
end

#messagesObject

Ephemeral conversation history supplied by the caller. Not stored in the database. Takes precedence over ‘thread_id` history when both are provided.



37
38
39
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 37

def messages
  @messages
end

#metadataObject

Flat caller-defined metadata stored separately from internal metadata for log display and filtering. Keys must be non-empty strings; values must be strings, numbers, booleans, or null.



34
35
36
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 34

def 
  @metadata
end

#streamingObject

When ‘true` the response is a Server-Sent Events stream.



28
29
30
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 28

def streaming
  @streaming
end

#thread_idObject

Find-or-create a persistent conversation thread by this caller- supplied string. Leave empty to start a stateless invocation.



25
26
27
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 25

def thread_id
  @thread_id
end

#userObject

Optional opaque caller identifier for audit logging.



31
32
33
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 31

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 43

def self.attribute_map
  {
    :'message' => :'message',
    :'agent' => :'agent',
    :'thread_id' => :'thread_id',
    :'streaming' => :'streaming',
    :'user' => :'user',
    :'metadata' => :'metadata',
    :'messages' => :'messages',
    :'image_urls' => :'image_urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 67

def self.openapi_types
  {
    :'message' => :'String',
    :'agent' => :'String',
    :'thread_id' => :'String',
    :'streaming' => :'Boolean',
    :'user' => :'String',
    :'metadata' => :'Hash<String, MetadataValue>',
    :'messages' => :'Array<AgentMessage>',
    :'image_urls' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      message == o.message &&
      agent == o.agent &&
      thread_id == o.thread_id &&
      streaming == o.streaming &&
      user == o.user &&
       == o. &&
      messages == o.messages &&
      image_urls == o.image_urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 217

def hash
  [message, agent, thread_id, streaming, user, , messages, image_urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @agent.nil?
    invalid_properties.push('invalid value for "agent", agent cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
# File 'lib/fetch_hive/generated/models/invoke_agent_request.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @message.nil?
  return false if @agent.nil?
  true
end