Class: FetchHive::Generated::PostPublicWorkspacesAgentsChats200ResponseChat
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FetchHive::Generated::PostPublicWorkspacesAgentsChats200ResponseChat
- Defined in:
- lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#agent ⇒ Object
Returns the value of attribute agent.
-
#generated_at ⇒ Object
Returns the value of attribute generated_at.
-
#id ⇒ Object
Returns the value of attribute id.
-
#last_message_content ⇒ Object
(value may be null).
-
#last_message_sent_at ⇒ Object
(value may be null).
-
#message_count ⇒ Object
Returns the value of attribute message_count.
-
#name ⇒ Object
(value may be null).
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostPublicWorkspacesAgentsChats200ResponseChat
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostPublicWorkspacesAgentsChats200ResponseChat
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::PostPublicWorkspacesAgentsChats200ResponseChat` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::PostPublicWorkspacesAgentsChats200ResponseChat`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'last_message_content') self. = attributes[:'last_message_content'] end if attributes.key?(:'last_message_sent_at') self. = attributes[:'last_message_sent_at'] end if attributes.key?(:'message_count') self. = attributes[:'message_count'] else self. = nil end if attributes.key?(:'generated_at') self.generated_at = attributes[:'generated_at'] else self.generated_at = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'agent') self.agent = attributes[:'agent'] end end |
Instance Attribute Details
#agent ⇒ Object
Returns the value of attribute agent.
35 36 37 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 35 def agent @agent end |
#generated_at ⇒ Object
Returns the value of attribute generated_at.
31 32 33 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 31 def generated_at @generated_at end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 18 def id @id end |
#last_message_content ⇒ Object
(value may be null)
24 25 26 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 24 def @last_message_content end |
#last_message_sent_at ⇒ Object
(value may be null)
27 28 29 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 27 def @last_message_sent_at end |
#message_count ⇒ Object
Returns the value of attribute message_count.
29 30 31 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 29 def @message_count end |
#name ⇒ Object
(value may be null)
21 22 23 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 21 def name @name end |
#status ⇒ Object
Returns the value of attribute status.
33 34 35 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 33 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 60 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'last_message_content' => :'last_message_content', :'last_message_sent_at' => :'last_message_sent_at', :'message_count' => :'message_count', :'generated_at' => :'generated_at', :'status' => :'status', :'agent' => :'agent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 267 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 84 def self.openapi_types { :'id' => :'String', :'name' => :'String', :'last_message_content' => :'String', :'last_message_sent_at' => :'Time', :'message_count' => :'Integer', :'generated_at' => :'Time', :'status' => :'String', :'agent' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 239 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && == o. && == o. && == o. && generated_at == o.generated_at && status == o.status && agent == o.agent end |
#eql?(o) ⇒ Boolean
254 255 256 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 254 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
260 261 262 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 260 def hash [id, name, , , , generated_at, status, agent].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 162 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @message_count.nil? invalid_properties.push('invalid value for "message_count", message_count cannot be nil.') end if @generated_at.nil? invalid_properties.push('invalid value for "generated_at", generated_at cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 289 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
186 187 188 189 190 191 192 193 194 195 |
# File 'lib/fetch_hive/generated/models/post_public_workspaces_agents_chats200_response_chat.rb', line 186 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @message_count.nil? return false if @generated_at.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["active", "archived"]) return false unless status_validator.valid?(@status) true end |