Class: FetchHive::Generated::RequestsApi
- Inherits:
-
Object
- Object
- FetchHive::Generated::RequestsApi
- Defined in:
- lib/fetch_hive/generated/api/requests_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_public_requests(id, opts = {}) ⇒ GetPublicRequests200Response
Get a request Returns the status, type, and timing metadata for a run.
-
#get_public_requests_with_http_info(id, opts = {}) ⇒ Array<(GetPublicRequests200Response, Integer, Hash)>
Get a request Returns the status, type, and timing metadata for a run.
-
#initialize(api_client = ApiClient.default) ⇒ RequestsApi
constructor
A new instance of RequestsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ RequestsApi
Returns a new instance of RequestsApi.
19 20 21 |
# File 'lib/fetch_hive/generated/api/requests_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/fetch_hive/generated/api/requests_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_public_requests(id, opts = {}) ⇒ GetPublicRequests200Response
Get a request
Returns the status, type, and timing metadata for a run. Pass the request_id returned when you invoked a prompt, workflow, agent, or Hive Agent.
27 28 29 30 |
# File 'lib/fetch_hive/generated/api/requests_api.rb', line 27 def get_public_requests(id, opts = {}) data, _status_code, _headers = get_public_requests_with_http_info(id, opts) data end |
#get_public_requests_with_http_info(id, opts = {}) ⇒ Array<(GetPublicRequests200Response, Integer, Hash)>
Get a request Returns the status, type, and timing metadata for a run. Pass the `request_id` returned when you invoked a prompt, workflow, agent, or Hive Agent.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/fetch_hive/generated/api/requests_api.rb', line 37 def get_public_requests_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: RequestsApi.get_public_requests ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling RequestsApi.get_public_requests" end # resource path local_var_path = '/public/requests/{id}'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GetPublicRequests200Response' # auth_names auth_names = opts[:debug_auth_names] || ['bearer_auth'] = opts.merge( :operation => :"RequestsApi.get_public_requests", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: RequestsApi#get_public_requests\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |