Class: FetchHive::Generated::SseChunk
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- FetchHive::Generated::SseChunk
- Defined in:
- lib/fetch_hive/generated/models/sse_chunk.rb
Overview
A single event in a Server-Sent Events stream. The type field is a runtime discriminator. Known values: delta, done, tool_start, tool_end, error.
Instance Attribute Summary collapse
-
#content ⇒ Object
Text delta content (present for type "delta").
-
#error ⇒ Object
Error message (present for "error" events).
-
#model ⇒ Object
Present on the final "done" event.
-
#observation ⇒ Object
Serialised JSON tool result (present for "tool_end").
-
#request_id ⇒ Object
Present on the final "done" event.
-
#tool_input ⇒ Object
Serialised JSON tool input (present for "tool_start").
-
#tool_name ⇒ Object
Tool name (present for "tool_start" / "tool_end").
-
#type ⇒ Object
Event type discriminator.
-
#usage ⇒ Object
Returns the value of attribute usage.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SseChunk
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SseChunk
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `FetchHive::Generated::SseChunk` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `FetchHive::Generated::SseChunk`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'content') self.content = attributes[:'content'] end if attributes.key?(:'request_id') self.request_id = attributes[:'request_id'] end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'tool_name') self.tool_name = attributes[:'tool_name'] end if attributes.key?(:'tool_input') self.tool_input = attributes[:'tool_input'] end if attributes.key?(:'observation') self.observation = attributes[:'observation'] end if attributes.key?(:'error') self.error = attributes[:'error'] end if attributes.key?(:'usage') self.usage = attributes[:'usage'] end end |
Instance Attribute Details
#content ⇒ Object
Text delta content (present for type "delta").
23 24 25 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 23 def content @content end |
#error ⇒ Object
Error message (present for "error" events).
41 42 43 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 41 def error @error end |
#model ⇒ Object
Present on the final "done" event.
29 30 31 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 29 def model @model end |
#observation ⇒ Object
Serialised JSON tool result (present for "tool_end").
38 39 40 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 38 def observation @observation end |
#request_id ⇒ Object
Present on the final "done" event.
26 27 28 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 26 def request_id @request_id end |
#tool_input ⇒ Object
Serialised JSON tool input (present for "tool_start").
35 36 37 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 35 def tool_input @tool_input end |
#tool_name ⇒ Object
Tool name (present for "tool_start" / "tool_end").
32 33 34 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 32 def tool_name @tool_name end |
#type ⇒ Object
Event type discriminator.
20 21 22 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 20 def type @type end |
#usage ⇒ Object
Returns the value of attribute usage.
43 44 45 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 43 def usage @usage end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 46 def self.attribute_map { :'type' => :'type', :'content' => :'content', :'request_id' => :'request_id', :'model' => :'model', :'tool_name' => :'tool_name', :'tool_input' => :'tool_input', :'observation' => :'observation', :'error' => :'error', :'usage' => :'usage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 190 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 71 def self.openapi_types { :'type' => :'String', :'content' => :'String', :'request_id' => :'String', :'model' => :'String', :'tool_name' => :'String', :'tool_input' => :'String', :'observation' => :'String', :'error' => :'String', :'usage' => :'TokenUsage' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && content == o.content && request_id == o.request_id && model == o.model && tool_name == o.tool_name && tool_input == o.tool_input && observation == o.observation && error == o.error && usage == o.usage end |
#eql?(o) ⇒ Boolean
177 178 179 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 177 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
183 184 185 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 183 def hash [type, content, request_id, model, tool_name, tool_input, observation, error, usage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 212 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 |
# File 'lib/fetch_hive/generated/models/sse_chunk.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |